<?php


namespace Drupal\stackpath\Plugin\Purge\TagsHeader;


use Drupal\purge\Plugin\Purge\TagsHeader\TagsHeaderBase;
use Drupal\purge\Plugin\Purge\TagsHeader\TagsHeaderInterface;
use Drupal\stackpath\StackPathApi;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Add X-Tag to the response headers.
 *
 * @PurgeTagsHeader(
 *   id = "stack_path",
 *   header_name = "X-Tag",
 * )
 */
class StackPathTagsHeader extends TagsHeaderBase implements TagsHeaderInterface {

  /**
   * @var \Drupal\stackpath\StackPathApi
   */
  protected $stackPath;

  /**
   * StackPathTagsHeader constructor.
   *
   * @param array $configuration
   * @param $plugin_id
   * @param $plugin_definition
   * @param \Drupal\stackpath\StackPathApi $stackPathApi
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, StackPathApi $stackPathApi) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->stackPath = $stackPathApi;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('stackpath.api')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getValue(array $tags) {
    $hashes = [];
    foreach ($tags as $tag) {
      $hashes[] = $this->stackPath->createHashTag($tag);
    }
    return implode(',', $hashes);
  }

}
